pub struct WebSocketClient { /* private fields */ }
Asynchronous WebSocket-based client for Misskey.

WebSocketClient can be constructed using WebSocketClient::connect or WebSocketClientBuilder. The latter is more flexible and intuitive.

You do not have to wrap this in Arc and Mutex to share it because WebSocketClient is already Clone and every methods of WebSocketClient takes &self, i.e. they does not require mutability.

Implementations

Connects to Misskey using WebSocket, and returns WebSocketClient.

Connects to Misskey using WebSocket with a given reconnect configuration, and returns WebSocketClient.

Creates a new builder instance with url. All configurations are set to default.

This function is identical to WebSocketClientBuilder::new.

Captures the note specified by id.

The returned SubNote implements Stream so that note events can be retrieved asynchronously via it.

Connects to the channel using request.

The returned Channel implements Stream and Sink so that you can exchange messages with channels on it.

Receive messages from the broadcast stream.

The returned Broadcast implements Stream so that broadcast events can be retrieved asynchronously via it.