pub struct WebSocketClientBuilder { /* private fields */ }
Builder for WebSocketClient.

Implementations

Creates a new builder instance with url.

All configurations are set to default.

Creates a new builder instance with the given host name host.

This method configures the builder with a URL of the form wss://{host}/streaming. All other configurations are set to default.

Sets an API token.

This method appends the given token as the i query parameter to the URL.

Specifies additional query parameters for the URL.

Sets whether or not to enable automatic reconnection.

Automatic reconnection is enabled by default (as per Default implementation for ReconnectConfig), and you can disable it with .auto_reconnect(false).

Sets an interval duration of automatic reconnection in seconds.

Sets an interval duration of automatic reconnection.

Specifies the condition for reconnecting.

Specifies whether to re-send messages that may have failed to be sent when reconnecting.

Finish this builder instance and connect to Misskey using this configuration.