Struct misskey_websocket::WebSocketClient
source · [−]pub struct WebSocketClient { /* private fields */ }Expand description
Asynchronous WebSocket-based client for Misskey.
WebSocketClient can be constructed using WebSocketClient::connect or
WebSocketClientBuilder.
The latter is more flexible and intuitive.
You do not have to wrap this in Arc and Mutex
to share it because WebSocketClient is already Clone and every methods of WebSocketClient takes &self, i.e. they does not require mutability.
Implementations
sourceimpl WebSocketClient
impl WebSocketClient
sourcepub async fn connect(url: Url) -> Result<WebSocketClient, Error>
pub async fn connect(url: Url) -> Result<WebSocketClient, Error>
Connects to Misskey using WebSocket, and returns WebSocketClient.
sourcepub async fn connect_with_config(
url: Url,
reconnect_config: ReconnectConfig
) -> Result<WebSocketClient, Error>
pub async fn connect_with_config(
url: Url,
reconnect_config: ReconnectConfig
) -> Result<WebSocketClient, Error>
Connects to Misskey using WebSocket with a given reconnect configuration, and returns WebSocketClient.
sourcepub fn builder<T>(url: T) -> WebSocketClientBuilder where
T: TryInto<Url>,
T::Error: Into<Error>,
pub fn builder<T>(url: T) -> WebSocketClientBuilder where
T: TryInto<Url>,
T::Error: Into<Error>,
Creates a new builder instance with url.
All configurations are set to default.
This function is identical to WebSocketClientBuilder::new.
sourcepub fn subnote<E, Id>(
&self,
note_id: Id
) -> BoxFuture<'static, Result<SubNote<E>, Error>> where
E: SubNoteEvent,
Id: Into<String>,
pub fn subnote<E, Id>(
&self,
note_id: Id
) -> BoxFuture<'static, Result<SubNote<E>, Error>> where
E: SubNoteEvent,
Id: Into<String>,